@@ -1,3 +1,6 @@
+/* This function computes the log-concave MLE of X_1, ..., X_n */
+/* using the "solvopt" implementation of Shor's r-algorithm */
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>  
@@ -11,6 +14,8 @@ int dim;
 double *xdata;
 int nouter;
 int truepoints;
+double Jtol;
+double trouble;
 
 /*  Function to be minimized: */
 double sigmaeff(double *y);
@@ -20,12 +25,12 @@ double dnull_entry();
 void subgradeff(double y[], double g[]);
 void null_entry();
 
-/* SolvOpt routing, modified to take extra parameters as arguments: */
+/* SolvOpt routine, modified to take extra parameters as arguments: */
 double solvopt2(int npoints, double *y_in, double sigma_ralg2(), void subgrad_ralg2(), double *opt_out, double fun(), void fun2(),double *parameters );
 
 void renormalise(double *y);
 
-void logconesteff (double *y_in, double *xdata_in, int *d_in, int *n_in, double *opt_out, double *sigmavalue_out, double *parameters, int *nouter_in)
+void logconesteff (double *y_in, double *xdata_in, int *d_in, int *n_in, double *opt_out, double *sigmavalue_out, double *parameters, double *Jtol_in, int *nouter_in)
 {
   /* Initialise */
   truepoints = *n_in;
@@ -33,6 +38,7 @@ void logconesteff (double *y_in, double *xdata_in, int *d_in, int *n_in, double
   xdata = xdata_in; 
   nouter = *nouter_in;
   npoints = truepoints+nouter;
+  Jtol = *Jtol_in;
 
   /* Use the solvopt algorithm */
     *sigmavalue_out=solvopt2(truepoints,y_in,&sigmaeff,&subgradeff,opt_out,&dnull_entry,&null_entry,parameters);
